Learn R Programming

BayesBridge (version 0.6)

diabetes: Blood and other measurements in diabetics

Description

The diabetes data 442 observations. The diabetes data structure is a list with three elements, which are listed below. This is the data used in Efron et al. (2002).

Arguments

Format

The list contains the following columns:
x
a matrix with 10 columns
y
a numeric vector
x2
a matrix with 64 columns

Details

The x matrix has been standardized to have unit L2 norm in each column and zero mean. The matrix x2 consists of x plus certain interactions.

References

Efron, Hastie, Johnstone and Tibshirani (2003) "Least Angle Regression" (with discussion) Annals of Statistics

LARS Package: http://cran.r-project.org/web/packages/lars/index.html.