powered by
The diabetes data 442 observations. The diabetes data structure is a list with three elements, which are listed below. This is the data used in Efron et al. (2002).
diabetes
LARS Package: http://cran.r-project.org/web/packages/lars/index.html.